package com.yyrh.sdk;

import android.app.Activity;


import com.yyrh.constant.Constants;
import com.yyrh.constant.SDKSettings;
import com.yyrh.easypermission.EasyPermission;
import com.yyrh.easypermission.GrantResult;
import com.yyrh.easypermission.Permission;
import com.yyrh.easypermission.PermissionRequestListener;
import com.yyrh.utils.PermissionUtils;
import com.yyrh.utils.Utils;
import com.yyrh.utils.YYLog;


import java.util.List;
import java.util.Map;

public class PermissionManager {



    public void requestPermission(final Activity activity, List<String> permissionList,final PermissionCallBack permissionCallBack){


        if (SDKSettings.isSkipPermission){
            YYLog.i("跳过权限申请");
            permissionCallBack.onResult(Result.SKIP);
            return;
        }

        if (PermissionUtils.checkIsHasPermission(activity,PermissionUtils.CODE_READ_PHONE_STATE) == 0 &&
                PermissionUtils.checkIsHasPermission(activity,PermissionUtils.CODE_WRITE_EXTERNAL_STORAGE) == 0){
            YYLog.i("已有权限");
            permissionCallBack.onResult(Result.GRANT);
            return;
        }

        if (Utils.getSharedPreferences(Constants.SP_KEY, "yyrhStopRequestPermission", activity).equals("1")){
            YYLog.i("玩家首次拒绝权限，第二次不再申请");
            permissionCallBack.onResult(Result.STOP);
            return;
        }



        if (SDKSettings.isStopRequestPermisson){
                Utils.setSharedPreferences(Constants.SP_KEY, "yyrhStopRequestPermission", "1", activity);
            }
        String[]  permissions = permissionList.toArray(new String[permissionList.size()]);

        EasyPermission.with(activity)
                .addPermissions(permissions)          //申请打电话权限
                .request(new PermissionRequestListener() {
                    @Override
                    public void onGrant(Map<String, GrantResult> result) {
                        //权限申请返回
                        if (result.get(Permission.READ_PHONE_STATE).getValue() == 0){
                            YYLog.i("授予权限");
                            permissionCallBack.onResult(Result.GRANT);

                        }else {
                            YYLog.i("拒绝权限");
                            permissionCallBack.onResult(Result.DENIED);
                        }

                    }

                    @Override
                    public void onCancel(String stopPermission) {
                        //在addRequestPermissionRationaleHandler的处理函数里面调用了NextAction.next(NextActionType.STOP,就会中断申请过程，直接回调到这里来

                    }
                });





    }


    public interface PermissionCallBack {

        void onResult(Result code);
    }


    public enum Result {

        /**
         * 授予权限
         */
        GRANT,

        /**
         * 拒绝权限
         */
        DENIED,
        /**
         * 跳过权限申请
         */
        SKIP,
        /**
         * 玩家首次拒绝权限，第二次不再申请
         */
        STOP


        }

}

